# porter
Porter is an Ingestion framework to ingest any type of source data into any destination. Its a PRO ELT !

:books: Documentation : https://porter-py.readthedocs.io/en/latest/

### Install
```shell
### PIP
# Install with ALl dependencies
pip install poetry-py

# Install on specific dependencies
pip install porter-py[dev,metadata,aws,govern,kube]


### POETRY
# Install with ALl dependencies
poetry add porter-py

# Install on specific dependencies
poetry add 'porter-py[dev,metadata,aws,govern,kube]'
```
